/*
 * ModelDRandomCspC - A generator for random binary symmetric constraint satisfaction problems.
 * Part of the RandomCsp library.
 * Copyright (C) 1998-2001 by J.I. van Hemert
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 * 
 * $Id: model_d.cc,v 1.1 2001/03/16 13:22:27 jano Exp $
 *
 */


#include "model_d.h"



void const ModelDRandomCspC::ProduceProblem ()
{
	unsigned long int c;
	unsigned int i, j, x, y = 0;

	Reset ();

	for (i = 0; i <= GetNumberOfVariables () - 1; i++)
		if (IsRandomDomainSize ())
			SetDomainSize (i, (random() % GetGlobalDomainSize ()) + 1);
		else
			SetDomainSize (i, GetGlobalDomainSize ());

	/* double -> unsigned int = ugly code! */
	c = (unsigned long int) (GetConnectivity () * GetNumberOfVariables () * (GetNumberOfVariables () - 1) * 0.5);

	while (c > 0)
	{
		do
		{
			i = random() % GetNumberOfVariables ();
			j = random() % GetNumberOfVariables ();
		}
		while (i == j);


		if (!IsConstraint (i, j))
		{
			AddConstraint (i, j);

			for (x = 0; x <= GetDomainSize (i) - 1; x++)
				for (y = 0; y <= GetDomainSize (j) - 1; y++)
					if ((random() % 1000) < (GetTightness () * 1000))
						AddConflict (i, j, x, y);
			c--;
		}
	}

} // ModelDRandomCspC::ProduceProblem



// eof model_d.cc
