/*
 * ModelFRandomCspC - A generator for random binary symmetric constraint satisfaction problems.
 * Part of the RandomCsp library.
 * Copyright (C) 1998-2000 by J.I. van Hemert
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 * 
 * $Id: model_f.cc,v 1.2 2002/06/18 14:12:03 jano Exp $
 *
 */


#include "model_f.h"



void const ModelFRandomCspC::ProduceProblem ()
{
	unsigned long int c;
	unsigned int i, j, x, y = 0;

	Reset ();

	for (i = 0; i <= GetNumberOfVariables () - 1; i++)
		if (IsRandomDomainSize ())
			SetDomainSize (i, (random() % GetGlobalDomainSize ()) + 1);
		else
			SetDomainSize (i, GetGlobalDomainSize ());

	/* double -> unsigned int = ugly code! */
	c = (unsigned long int) (GetTightness () * GetConnectivity () * GetNumberOfVariables () * (GetNumberOfVariables () - 1) * 0.5 * GetGlobalDomainSize() * GetGlobalDomainSize());

	/* First perform Model E way of creating nogoods */
	while (c > 0)
	{
		do
		{
			i = random() % GetNumberOfVariables ();
			j = random() % GetNumberOfVariables ();
		}
		while (i == j);


		if (!IsConstraint (i, j))
		{
			AddConstraint (i, j);
		}

		x = random() % GetDomainSize (i);
		y = random() % GetDomainSize (j);

		if (!IsConflict (i, j, x, y))
		{
			AddConflict (i, j, x, y);
		}
		c--;
	}

	/* create a graph with exactly p_1 n (n-1)/2 edges and remove nogoods that are not in this graph */
	/* we translate this to: throw away (1-p_1)n(n-1/2 constraints */
	c = (unsigned long int) ( (1.0-GetConnectivity ()) * GetNumberOfVariables () * (GetNumberOfVariables () - 1) * 0.5);
	while (c > 0)
	{
		do
		{
			i = random() % GetNumberOfVariables ();
			j = random() % GetNumberOfVariables ();
		}
		while (i == j);


		if (IsConstraint (i, j))
		{
			RemoveConstraint(i, j);

			c--;
		}
	}

} // ModelFRandomCspC::ProduceProblem



// eof model_f.cc
