
/*
 * ModelGRandomCspC - A generator for random binary symmetric constraint satisfaction problems.
 * Part of the RandomCsp library.
 * Copyright (C) 1998-2000 by J.I. van Hemert
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 * 
 * $Id: model_g.cc,v 1.3 2004/02/16 16:06:52 jvhemert Exp $
 *
 */


#include "model_g.h"

#include <cmath>
#include <climits>


void const ModelGRandomCspC::ProduceProblem ()
{
	unsigned long int c = 0;
	unsigned int i, j, x, y = 0;

	Reset ();

	for (i = 0; i <= GetNumberOfVariables () - 1; i++)
		if (IsRandomDomainSize ())
			SetDomainSize (i, (random() % GetGlobalDomainSize ()) + 1);
		else
			SetDomainSize (i, GetGlobalDomainSize ());

	/** double -> unsigned int = ugly code! */
	c = (unsigned long int) (GetTightness () * GetNumberOfVariables () * (GetNumberOfVariables () - 1) * 0.5 * GetGlobalDomainSize() * GetGlobalDomainSize());

	bool not_safe = false;

	while (c > 0)
	{
		int max_tries = 10000;
		do
		{
			do
			{
				i = random() % GetNumberOfVariables ();
				j = random() % GetNumberOfVariables ();
			}
			while (i == j);

			x = GetNextGeometric(GetConnectivity());
			y = GetNextGeometric(GetConnectivity());

			if (max_tries > 0)
				max_tries--;

		}
		while ((x == 0 && y == 0) || (x < 0) || (y < 0) || (y >= GetDomainSize(j)) || (x >= GetDomainSize(i)) || (IsConflict(i, j, x, y) && max_tries > 0));

		if (max_tries == 0)
		{
			//DEBUGcerr << "*";
			not_safe = true;
		}

		if (!IsConstraint(i, j)) {
			AddConstraint(i,j);
		}
		AddConflict(i, j, x, y);
		c--;
	}

	if (not_safe)
	{
		Error->Give ("Generated a problem that might not be deceptive.", Error->warning);
	}

} // ModelGRandomCspC::ProduceProblem


int ModelGRandomCspC::GetNextGeometric
(
	double p
)
{
	double u = (random() % 1000000) / 1000000.0;

	//cerr << u << " " << (int) ( (log(u) / log(1.0-p)) ) << " " << p << endl;
	return (int)  (log(u) / log(1.0-p)) ;
}


// eof model_g.cc
