
/*
 * ModelGRandomCspC - A generator for random binary symmetric constraint satisfaction problems.
 * Part of the RandomCsp library.
 * Copyright (C) 1998-2000 by J.I. van Hemert
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 * 
 * $Id: model_g.h,v 1.2 2001/05/30 12:22:28 jano Exp $
 *
 */


#ifndef _ModelGRandomCspC_H
#define _ModelGRandomCspC_H


#include "randomcsp4.h"


/**
 * This class is capable of producing Random Binary Constraint Satisfaction
 * Problems. The usage is quite simple. After the creation of a object of this
 * class with all the correct parameters, the InitRandomGenerator function
 * should be used to set the seeds for the randomgenerator. This has to be done
 * at least once. Then a problem can be generated with the ProduceProblem
 * function and a filename can be produced with the ProduceFileName function
 *
 * Produce a constraint satisfaction method using such that it is GA-Hard. That
 * is, the problem is very deceptive and will cause a standard EA to get stuck
 * in a trap, Idea originates from research done in Antwerp by J.I. van Hemert
 * (me), L. Schoofs and B. Naudts.
 *
 * By using a geometric distribution we bias which value pairs get the most
 * conflicts added. The lower the value of a variable the more chance it has to
 * be selected for a conflict pair. One exception is the pair (0,0), this pair
 * is *never* formed, thereby making sure a solution always exist, namely
 * 0,0,0,...,0.
 *
 * @memo Random Constraint Satisfaction Problems
 *
 * @author J.I. van Hemert
 * @version 1.4
 *
 */

class ModelGRandomCspC: 
	public RandomCsp4C
{
	public:

		
		ModelGRandomCspC
		(
			NumberOfVariablesT const iNumberOfVariables,
			DomainSizeT const iDomainSize,
			bool const iRandomDomainSize,
			TightnessT const iTightness,
			ConnectivityT const iConnectivity
		): RandomCsp4C (iNumberOfVariables, iDomainSize, iRandomDomainSize, iTightness, iConnectivity) {};

		/**
		 * Produce a constraint satisfaction problem using method G (GA-hard)
		 *
		 * @memo Producing a Random CSP
		 *
		 * @return nothing.
		 * 
		 * @author J.I. van Hemert
		 * @version 1.5
		 *
		 */

		void const ProduceProblem ();

		void ProduceFileName (char * FileName)
		{
			strcat (FileName, "mg_");
			RandomCsp4C::ProduceFileName(FileName);
		}

	protected:

		int GetNextGeometric (double p);

	private:

}; // ModelGRandomCspC


#endif

// eof model_g.h
