/*
 * RandomCsp3 - An empty class for random binary symmetric constraint satisfaction problems.
 * Part of the RandomCsp3 library.
 * Copyright (C) 1998-2000 by J.I. van Hemert
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 * 
 * $Id: randomcsp3.cc,v 1.2 2000/11/28 11:36:42 jano Exp $
 *
 */


#include "randomcsp3.h"



RandomCsp3C::RandomCsp3C
(
		NumberOfVariablesT const iNumberOfVariables,
		DomainSizeT const iDomainSize,
		bool const iRandomDomainSize,
		TightnessT const iTightness
):
	RandomCspA (iNumberOfVariables)
{

	RandomDomainSize = iRandomDomainSize;

	DomainSize = iDomainSize;
	if (DomainSize < 1)
		Error->Give ("Domainsize should be larger than 0.", Error->error);

	Tightness = iTightness;
	if (Tightness < 0)
		Error->Give ("Tightness should be 0 or higher.", Error->error);

} // RandomCsp3C::RandomCsp3C



RandomCsp3C::~RandomCsp3C ()
{
} // RandomCsp3C::~RandomCsp3C





void const RandomCsp3C::ProduceProblem ()
{
} // RandomCsp3C::ProduceProblem



void RandomCsp3C::ProduceFileName
(
	char * FileName
)
{
	char * Tmp;
	Tmp = new char [70];

#if defined (Linux)
	snprintf (Tmp, 30, "v%i_d%i", GetNumberOfVariables (), DomainSize);
#else
	sprintf (Tmp, "v%i_d%i", GetNumberOfVariables (), DomainSize);
#endif
	strcat (FileName, Tmp);

	if (RandomDomainSize)
		strcat (FileName, "_r");
	else
		strcat (FileName, "_c");

#if defined (Linux)
	snprintf (Tmp, 60, "_t%.10g_s%i.csp", Tightness, GetSeed());
#else
	sprintf (Tmp, "_t%.10g_s%i.csp", Tightness, GetSeed());
#endif

	strcat (FileName, Tmp);

	delete Tmp;
	
} // RandomCsp3C::ProduceFileName



// eof pprosser.cc
