/*
 * StaticCspC - for loading files from disk
 * Part of the RandomCsp library.
 * Copyright (C) 1998-2000 by J.I. van Hemert
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 * 
 * $Id: static_csp.h,v 1.4 2004/02/16 16:06:53 jvhemert Exp $
 *
 */


#ifndef _RandomCspA_H
#define _RandomCspA_H


#include <cstdlib>
#include "csp.h"


/**
 * This class is only useful to load instances from disk.
 *
 * @memo Random Constraint Satisfaction Problems
 *
 * @author J.I. van Hemert @version 1.2
 *
 */

class StaticCspC: 
	public CspC
{
	public:

		/**
		 * Constructor copies all the parameters for further usage.
		 *
		 * @memo Constructor
		 *
		 * @param iFileName Filename of instance on disk
		 *
		 * @return nothing.
		 *
		 * @author J.I. van Hemert
		 * @version 1.2
		 *
		 */

		StaticCspC
		(
		 	char * iFileName
		): CspC(1), FileName(iFileName)
		{
			if (iFileName==0)
				LoadFromStdin();
			else
				LoadFromFile(iFileName);
		};



		/**
		 * For C++'s sake we have to implement the virtual destructor.
		 *
		 * @memo Destructor
		 *
		 * @return nothing.
		 *
		 * @author J.I. van Hemert
		 * @version 1.2
		 *
		 */

		~StaticCspC () {};


		void ProduceFileName
		(
			char * ioFileName
		)
		{
			ioFileName = FileName;
		};


	protected:

		char * FileName;

	private:

}; // StaticCspC


#endif

// eof static_csp.h
